package com.jeeplus.business.project.service;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.extra.spring.SpringUtil;
import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.jeeplus.assess.program.configuration.projectList.domain.ProgramProjectListInfo;
import com.jeeplus.assess.program.configuration.projectList.service.dto.ProgramAuditAssessPeopleDto;
import com.jeeplus.assess.program.configuration.projectList.service.dto.ProgramAuditDto;
import com.jeeplus.assess.program.configuration.projectList.service.dto.ProjectListDto;
import com.jeeplus.assess.workContract.mapper.WorkContractInfoMapper;
import com.jeeplus.business.project.domain.JyProject;
import com.jeeplus.business.project.domain.JyProjectAudit;
import com.jeeplus.business.project.domain.JyProjectMembers;
import com.jeeplus.business.project.mapper.JyProjectAuditMapper;
import com.jeeplus.business.project.mapper.JyProjectMapper;
import com.jeeplus.business.project.mapper.JyProjectMemberMapper;
import com.jeeplus.business.project.service.dto.JyProjectAuditDTO;
import com.jeeplus.business.project.service.dto.JyProjectDTO;
import com.jeeplus.business.project.service.mapstruct.JyProjectAuditWrapper;
import com.jeeplus.business.workClientInfo.domain.JyWorkClientLinkman;
import com.jeeplus.business.workClientInfo.mapper.JyWorkClientInfoMapper;
import com.jeeplus.business.workClientInfo.mapper.JyWorkClientLinkmanMapper;
import com.jeeplus.business.workContractInfo.domain.JyWorkContractInfo;
import com.jeeplus.business.workContractInfo.mapper.JyWorkContractInfoMapper;
import com.jeeplus.business.workContractInfo.service.JyWorkContractService;
import com.jeeplus.business.workContractInfo.service.dto.JyWorkContractInfoDto;
import com.jeeplus.common.TokenProvider;
import com.jeeplus.core.query.QueryWrapperGenerator;
import com.jeeplus.flowable.feign.IFlowableApi;
import com.jeeplus.sys.domain.DictValue;
import com.jeeplus.sys.domain.WorkAttachmentInfo;
import com.jeeplus.sys.feign.IUserApi;
import com.jeeplus.sys.feign.IWorkAttachmentApi;
import com.jeeplus.sys.mapper.DictValueMapper;
import com.jeeplus.sys.service.dto.UserDTO;
import org.apache.commons.compress.utils.Lists;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.RequestParam;

import javax.annotation.Resource;
import java.text.SimpleDateFormat;
import java.util.*;


@Service
public class JyProjectService {

    @Resource
    private JyProjectMapper jyProjectMapper;

    @Resource
    private IFlowableApi flowTaskService;

    @Resource
    private JyWorkContractInfoMapper jyWorkContractInfoMapper;

    @Resource
    private JyWorkClientInfoMapper jyWorkClientInfoMapper;

    @Resource
    private JyProjectMemberMapper jyProjectMemberMapper;


    @Resource
    private JyWorkClientLinkmanMapper jyWorkClientLinkmanMapper;

//    @Autowired
//    private JyWorkContractService jyWorkContractService;

    @Resource
    private DictValueMapper dictValueMapper;

    @Resource
    private JyProjectAuditMapper jyProjectAuditMapper;

    @Resource
    private WorkContractInfoMapper workContractInfoMapper;


    /**
     * 项目登记列表
     * @param page
     * @param info
     * @return
     */
    public IPage<JyProject> list(Page<JyProject> page, JyProject info) throws Exception {
        QueryWrapper<JyProject> wrapper = QueryWrapperGenerator.buildQueryCondition(info, JyProject.class);
        if (ObjectUtil.isNotEmpty(info) && StringUtils.isNotBlank(info.getCreateById())) {
            wrapper.eq("a.create_by_id", info.getCreateById());
        }
        wrapper.eq("a.del_flag", "0");
        //创建时间
        if (info.getCreateDates() != null && info.getCreateDates().length > 0) {
            wrapper.between("a.create_time", info.getCreateDates()[0], info.getCreateDates()[1]);
        }
        //一审状态
        if (StringUtils.isNotBlank(info.getFirstInstanceStatus())){
            wrapper.eq("a.first_instance_status", info.getFirstInstanceStatus());
        }
        //二审状态
        if (StringUtils.isNotBlank(info.getSecondInstanceStatus())){
            wrapper.eq("a.second_instance_status", info.getSecondInstanceStatus());
        }
        //三审状态
        if (StringUtils.isNotBlank(info.getThirdInstanceStatus())){
            wrapper.eq("a.third_instance_status", info.getThirdInstanceStatus());
        }
        //项目编号
        if (StringUtils.isNotBlank(info.getNo())){
            wrapper.like("a.no",info.getNo());
        }
        //项目名称
        if (StringUtils.isNotBlank(info.getName())){
            wrapper.like("a.name",info.getName());
        }
        //项目负责人
        if (StringUtils.isNotBlank(info.getProjectLeader())){
            wrapper.like("a.project_leader",info.getProjectLeader());
        }
        //合同名称
        if (StringUtils.isNotBlank(info.getContractName())){
            wrapper.like("a.contract_name",info.getContractName());
        }
        //委托方
        if (StringUtils.isNotBlank(info.getClientName())){
            wrapper.like("a.client_name",info.getClientName());
        }
        //登记状态
        if (StringUtils.isNotBlank(info.getStatus())){
            wrapper.eq("a.status", info.getStatus());
        }
        //报告签发
        if (StringUtils.isNotBlank(info.getReportIssuance())){
            wrapper.eq("a.report_issuance", info.getReportIssuance());
        }
        //外审
        if (StringUtils.isNotBlank(info.getOutIssuance())){
            wrapper.eq("a.out_issuance", info.getOutIssuance());
        }
        //报批签发
        if (StringUtils.isNotBlank(info.getReportSubmit())){
            wrapper.eq("a.report_submit", info.getReportSubmit());
        }
        //归档状态
        if (StringUtils.isNotBlank(info.getReviewStatus())){
            wrapper.eq("a.review_status", info.getReviewStatus());
        }
        IPage<JyProject> pageList = jyProjectMapper.findPageList(page, wrapper);
        pageList.getRecords().stream().forEach(item ->{
            // 项目登记
            if (StringUtils.isNotBlank(item.getTaskId()) && StringUtils.isNotBlank(item.getStatus())) {
                if ("2".equals(item.getStatus())) { // “审核中”的数据要获取数据审核人
                    item.setAuditUserIds(flowTaskService.getTaskAuditUsers(item.getTaskId()));  // 获取数据审核人
                }
            }
            //合同名称及委托方联系人
            if (StringUtils.isEmpty(item.getContractName())){
                item.setContractName("暂无合同");
                item.setPrimaryLinkman(item.getClientName());
            }
        });
        return pageList;
    }

    /**
     * 查询当前登录人所属项目组的项目
     * @return
     */
    public ResponseEntity<List<String>> getHaveProjectIds() {
        UserDTO userDTO = SpringUtil.getBean ( IUserApi.class ).getByToken(TokenProvider.getCurrentToken());
        return ResponseEntity.ok(jyProjectMapper.getHaveProjectIds(userDTO));
    }

    public IPage<JyWorkContractInfo> findContractPageList(JyWorkContractInfoDto dto, Page<JyWorkContractInfo> page) {
        IPage<JyWorkContractInfo> contractPageList = jyProjectMapper.findContractPageList(page, dto);
        contractPageList.getRecords().stream().forEach(i->{
        //合同类型查询
        StringBuffer stringBuffer = new StringBuffer();
        String newType="";
        if (StringUtils.isNotEmpty(i.getContractType())){
            if (!i.getContractType().contains(",")){
                String type= jyWorkContractInfoMapper.findType(i.getContractType());
                i.setContractType(type);
            }else {
                String[] split = i.getContractType().split(",");
                for (String s : split) {
                    String type= jyWorkContractInfoMapper.findType2(s);
                    stringBuffer.append(type+",");
                    newType=stringBuffer.substring(0,stringBuffer.lastIndexOf(","));
                    i.setContractType(newType);
                }
            }
        }
        //主委托方联系人信息查询
            List<JyWorkClientLinkman> jyWorkClientLinkmen=jyWorkClientInfoMapper.getByNameInfo(i.getLinkmanId());
            i.setLinkmanList(jyWorkClientLinkmen);
        });

        return contractPageList;
    }

    /**
     * 项目保存或修改
     * @param dto
     * @return
     * @throws Exception
     */
    public String save(JyProjectDTO  dto) throws Exception{
        if (StringUtils.isNotEmpty(dto.getId())) {
            return update(dto);
        }
        return add(dto);
    }


    public String add(JyProjectDTO dto) throws Exception{
        String currentToken = TokenProvider.getCurrentToken();
        JyProject jyProject = new JyProject();
        //获取当前登录人信息
        UserDTO userDTO = SpringUtil.getBean ( IUserApi.class ).getByToken(TokenProvider.getCurrentToken());
        // 保存项目管理列表信息
        BeanUtils.copyProperties(dto, jyProject);
        String projectNo = "";

        String id = UUID.randomUUID().toString().replace("-", "");
        //生成项目编号
        if (dto.getContractStatus().equals("0")){
            projectNo = SpringUtil.getBean ( IWorkAttachmentApi.class ).genSerialNum(userDTO.getCompanyDTO().getId(), JyProjectDTO.BIZ_CODE,currentToken);
        }else {
            JyWorkContractInfo byId = jyWorkContractInfoMapper.findById(dto.getContractId());
            Integer projectNum=jyProjectMapper.getProByContractId(dto.getContractId());
            Integer count=0;
            if (projectNum == 0){
                projectNo=byId.getNo()+"-0"+(count+1);
            }else {
                projectNo=byId.getNo()+"-0"+(projectNum+1);
            }
        }
        jyProject.setId(id);//生成主键id
        jyProject.setName(dto.getName());//项目名称
        if (dto.getContractStatus().equals("0")){
            jyProject.setContractName("");//合同名称
        }else {
            jyProject.setContractName(dto.getContractName());//合同名称
        }
        jyProject.setNo(projectNo); //项目编号
        jyProject.setContractId(dto.getContractId()); //合同编号
        List<JyWorkClientLinkman> clientList = dto.getClientList();
        for (JyWorkClientLinkman jyWorkClientLinkman : clientList) {
            jyProject.setClient(jyWorkClientLinkman.getId());//联系人id
            jyProject.setClientName(jyWorkClientLinkman.getName());//联系人姓名
        }
        jyProject.setProjectLeader(dto.getProjectLeader());//项目负责人
        jyProject.setProjectPlace(dto.getProjectPlace());//项目所在地
        jyProject.setStatus(dto.getStatus());
        jyProject.setDelFlag(0);
        jyProject.setContractStatus(dto.getContractStatus());//合同情况
        jyProject.setSpecial(dto.getSpecial());//特殊要求
        jyProject.setProjectOverview(dto.getProjectOverview());//工程概况
        jyProject.setBuildPlace(dto.getBuildPlace());//建设地点
        jyProjectMapper.insert(jyProject);
        //保存项目组成员
        List<String> strings = new ArrayList<>();
        strings.add(userDTO.getId());
        strings.add(dto.getProjectLeader());
        for (String string : strings) {
            JyProjectMembers jyProjectMembers = new JyProjectMembers();
            String memberId = UUID.randomUUID().toString().replace("-", "");
            jyProjectMembers.setId(memberId);
            jyProjectMembers.setCreateById(userDTO.getId());
            jyProjectMembers.setCreateTime(new Date());
            jyProjectMembers.setUpdateById(userDTO.getId());
            jyProjectMembers.setUpdateTime(new Date());
            jyProjectMembers.setProjectId(id);
            jyProjectMembers.setUserId(string);
            jyProjectMembers.setStatus("0");
            jyProjectMemberMapper.insert(jyProjectMembers);
        }
        //三级校审添加
        JyProjectAudit jyProjectAudit1 = new JyProjectAudit();
        jyProjectAudit1.setProjectId(jyProject.getId());
        jyProjectAudit1.setStatus("0");
        jyProjectAudit1.setAuditLevel("1");
        jyProjectAudit1.setExceedTimeStatus("0");
        jyProjectAuditMapper.insert(jyProjectAudit1);
        JyProjectAudit jyProjectAudit2 = new JyProjectAudit();
        jyProjectAudit2.setProjectId(jyProject.getId());
        jyProjectAudit2.setStatus("0");
        jyProjectAudit2.setAuditLevel("2");
        jyProjectAuditMapper.insert(jyProjectAudit2);
        JyProjectAudit jyProjectAudit3 = new JyProjectAudit();
        jyProjectAudit3.setProjectId(jyProject.getId());
        jyProjectAudit3.setStatus("0");
        jyProjectAudit3.setAuditLevel("3");
        jyProjectAuditMapper.insert(jyProjectAudit3);



        // 保存附件信息
        if (CollectionUtils.isNotEmpty(dto.getFiles())) {
            saveFiles(dto.getFiles(), userDTO, id);
        }
        return id;
    }

    public String update(JyProjectDTO dto) throws Exception{
        String currentToken = TokenProvider.getCurrentToken();
        //获取当前登录人信息
        UserDTO userDTO = SpringUtil.getBean ( IUserApi.class ).getByToken(TokenProvider.getCurrentToken());
        // 修改项目管理列表主表信息
        JyProject jyProject = new JyProject();
        BeanUtils.copyProperties(dto, jyProject);
        jyProject.setUpdateById(userDTO.getId());
        jyProject.setUpdateTime(new Date());
        jyProject.setDelFlag(0);
        jyProjectMapper.updateById(jyProject);
        // 修改附件信息
        if (CollectionUtils.isNotEmpty(dto.getFiles())) {
            updateFiles(dto.getFiles(), userDTO, dto.getId());
        }
        return dto.getId();
    }

    /**
     * 修改附件信息
     * @param list 待修改的附件列表
     * @param userDTO 当前登录用户
     * @param id 关联id
     */
    @Transactional(rollbackFor = Exception.class)
    public void updateFiles(List<WorkAttachmentInfo> list, UserDTO userDTO, String id) {
        int j = 1;
        String names = new String();
        //表中存在，但是传过来不存在，说明已删除，表中数据也要删除
        for (WorkAttachmentInfo dto : list) {
            names = names + "," +dto.getUrl();
        }
        //查询保存的附件信息
        List<WorkAttachmentInfo> infoList = jyProjectMapper.findFileList(id);
        if (CollectionUtil.isNotEmpty(infoList)) {
            for (WorkAttachmentInfo i : infoList) {
                if (!names.contains(i.getUrl())) {
                    SpringUtil.getBean ( IWorkAttachmentApi.class ).deleteById(i.getId());
                }
            }
        }
        //保存信息
        for (WorkAttachmentInfo dto : list) {
            //判断是否存在
            Integer isExit = jyProjectMapper.findIsExit(id, dto.getName());
            if (isExit == 0) {
                WorkAttachmentInfo i = new WorkAttachmentInfo();
                //包含了url、size、name
                i.setId(UUID.randomUUID().toString().replace("-", ""));
//                i.getCreateBy().setId(userDTO.getId());
                i.setCreateTime(new Date());
//                i.getUpdateBy().setId(userDTO.getId());
                i.setUpdateTime(new Date());
                i.setDelFlag(0);
                i.setUrl(dto.getUrl());
                //文件类型处理
                List<String> strings = Arrays.asList(dto.getName().split("\\."));
                if (CollectionUtil.isNotEmpty(strings)) {
                    i.setType(strings.get(1));
                }
                i.setAttachmentId(id);
                i.setAttachmentName(dto.getName());
                i.setAttachmentFlag("jyProject");
                i.setFileSize(dto.getSize());
                i.setSort(j);
                Map<String,String> map = new HashMap<>();
                String workAttachment = JSON.toJSONString((i));
                String userDTOInfo = JSON.toJSONString((userDTO));
                map.put("workAttachment",workAttachment);
                map.put("userDTO",userDTOInfo);
                SpringUtil.getBean ( IWorkAttachmentApi.class ).insertWorkAttachment(map);
                j++;
            }
        }
    }

    /**
     * 保存附件信息
     * @param list 待保存的附件列表
     * @param userDTO 当前登录用户
     * @param id 关联id
     */
    @Transactional(rollbackFor = Exception.class)
    public void saveFiles(List<WorkAttachmentInfo> list, UserDTO userDTO, String id) {
        int j = 1;
        for (WorkAttachmentInfo dto : list) {
            WorkAttachmentInfo i = new WorkAttachmentInfo();
            //包含了url、size、name
            i.setId(UUID.randomUUID().toString().replace("-", ""));
//            i.getCreateBy().setId(userDTO.getId());
            i.setCreateTime(new Date());
//            i.getUpdateBy().setId(userDTO.getId());
            i.setUpdateTime(new Date());
            i.setDelFlag(0);
            i.setUrl(dto.getUrl());
            //文件类型处理
            List<String> strings = Arrays.asList(dto.getName().split("\\."));
            if (CollectionUtil.isNotEmpty(strings)) {
                i.setType(strings.get(1));
            }
            i.setAttachmentId(id);
            i.setAttachmentName(dto.getName());
            i.setAttachmentFlag("jyProject");
            i.setFileSize(dto.getSize());
            i.setSort(j);
            Map<String,String> map = new HashMap<>();
            String workAttachment = JSON.toJSONString((i));
            String userDTOInfo = JSON.toJSONString((userDTO));
            map.put("workAttachment",workAttachment);
            map.put("userDTO",userDTOInfo);
            SpringUtil.getBean ( IWorkAttachmentApi.class ).insertWorkAttachment(map);
            j++;
        }
    }

    public JyProjectDTO findById(String id) {
        JyProjectDTO jyProjectDTO = new JyProjectDTO();
        // 查询主表信息
        JyProject info = jyProjectMapper.getById(id);
        //保存项目信息
        if (ObjectUtil.isNotEmpty(info)){
            BeanUtils.copyProperties(info, jyProjectDTO);
        }
        // 查询联系人列表
        ArrayList<JyWorkClientLinkman> jyWorkClientLinkmen = new ArrayList<>();
        JyWorkClientLinkman jyWorkClientLinkman = jyWorkClientLinkmanMapper.selectById(info.getClient());
        if (ObjectUtil.isNotEmpty(jyWorkClientLinkman)){
            jyWorkClientLinkmen.add(jyWorkClientLinkman);
            jyProjectDTO.setClientList(jyWorkClientLinkmen);
        }
        // 查询成员列表
        LambdaQueryWrapper<JyProjectMembers> memberWrapper = new LambdaQueryWrapper<>();
        memberWrapper.eq(JyProjectMembers::getProjectId, id);
        memberWrapper.eq(JyProjectMembers::getDelFlag, 0);
        List<JyProjectMembers> members = jyProjectMemberMapper.selectList(memberWrapper);
        if (CollectionUtils.isNotEmpty(members)) {
            members.stream().forEach(member -> {
                if (StringUtils.isNotBlank(member.getUserId())) {
                    UserDTO byId = SpringUtil.getBean ( IUserApi.class ).getById(member.getUserId());
                    if (ObjectUtil.isNotEmpty(byId)) {
                        member.setName(byId.getName());
//                        member.setOfficeName(byId.getOfficeDTO().getName());
//                        member.setRoleName(byId.getRoleDTO().getName());
//                        member.setMobile(byId.getMobile());
                        member.setStatus("0");
                    }
                }
            });
            jyProjectDTO.setProjectMembers(members);
        }
        //合同类型查询
        if (StringUtils.isNotBlank(info.getContractId())){
            String type="";
            if (!info.getContractType().contains(",")){
                jyProjectDTO.setContractType(info.getContractType());
            }else {
                String[] split = info.getContractType().split(",");
                for (String s : split) {
                    DictValue dictValue = dictValueMapper.selectById(s);
                    type=dictValue.getLabel()+",";
                    String newType=type.substring(0,type.lastIndexOf(","));
                    jyProjectDTO.setContractType(newType);
                }
            }
        }


        // 查询附件信息
        List<WorkAttachmentInfo> files = jyWorkContractInfoMapper.findDtos(id);
        if (CollectionUtils.isNotEmpty(files)) {
            for (WorkAttachmentInfo i : files) {
                i.setCreateBy(SpringUtil.getBean ( IUserApi.class ).getById(i.getBy()));
            }
            jyProjectDTO.setFiles(files);
        }
        return jyProjectDTO;
    }


    /**
     * 根据id修改status
     */
    public void updateStatusById(JyProjectDTO jyProjectDTO) {
        jyProjectMapper.updateStatusById(jyProjectDTO.getId(), jyProjectDTO.getStatus());
        //获取到项目登记通过的信息
        JyProject byId = jyProjectMapper.getById(jyProjectDTO.getId());
        if (byId.getStatus().equals("5")){
            //获取到项目校审一级的信息
           JyProjectAudit jyProjectAudit= jyProjectAuditMapper.getIdByProId(byId.getId());
           //设置项目登记通过的时间
            jyProjectAudit.setProjectAgreeTime(byId.getUpdateTime());
            jyProjectAuditMapper.updateById(jyProjectAudit);
        }
    }


    public String deleteById(String id) {
        jyProjectMapper.deleteById(id);
        jyProjectMemberMapper.deleteByInfoId(id);
        // 附件删除
//        LambdaQueryWrapper<WorkAttachmentInfo> wrapper = new LambdaQueryWrapper<>();
//        wrapper.eq(WorkAttachmentInfo::getAttachmentId, id);
        SpringUtil.getBean ( IWorkAttachmentApi.class ).deleteByAttachmentId(id);
        return "删除项目成功";
    }

    /**
     * 根据当前登录人获取项目信息
     * @param page
     * @param info
     * @return
     */
    public IPage<JyProject> getByCreate(Page<JyProject> page, JyProject info) throws Exception {
        //获取当前登录人信息
        UserDTO userDTO = SpringUtil.getBean ( IUserApi.class ).getByToken(TokenProvider.getCurrentToken());
        QueryWrapper<JyProject> wrapper = QueryWrapperGenerator.buildQueryCondition(info, JyProject.class);
        //创建时间
        if (info.getCreateDates() != null && info.getCreateDates().length > 0) {
            wrapper.between("a.create_time", info.getCreateDates()[0], info.getCreateDates()[1]);
        }
        //项目编号
        if (StringUtils.isNotBlank(info.getNo())){
            wrapper.like("a.no",info.getNo());
        }
        //项目名称
        if (StringUtils.isNotBlank(info.getName())){
            wrapper.like("a.name",info.getName());
        }
        IPage<JyProject> projectIPage=jyProjectMapper.getByCreate(userDTO.getId(),page,wrapper);
        return projectIPage;
    }

    /**
     * 获取三级校审信息
     * @param id
     * @return
     */
    public JyProjectAuditDTO findByIdAudit(String id) {
        //根据id获取校审信息
        JyProjectAuditDTO jyProjectAuditDTO=jyProjectAuditMapper.findByIdAudit(id);
        // 查询附件信息
        List<WorkAttachmentInfo> files = workContractInfoMapper.findDtos(id);
        if (CollectionUtils.isNotEmpty(files)) {
            for (WorkAttachmentInfo i : files) {
                i.setCreateBy(SpringUtil.getBean ( IUserApi.class ).getById(i.getBy()));
            }
            jyProjectAuditDTO.setWorkAttachmentDtoList(files);
        }
        //获取项目信息
        JyProjectDTO byId = findById(jyProjectAuditDTO.getProjectId());
        jyProjectAuditDTO.setJyProjectList(byId);


        //根据项目的id去查校审的id
        List<String> ids = jyProjectAuditMapper.getIDsByProId(jyProjectAuditDTO.getProjectId());
        if (ids.size() >= 1) {
            jyProjectAuditDTO.setId1(ids.get(0));
        }
        if (ids.size() >= 2) {
            jyProjectAuditDTO.setId2(ids.get(1));
        }
        if (ids.size() >= 3) {
            jyProjectAuditDTO.setId3(ids.get(2));
        }
        return jyProjectAuditDTO;

    }

    /**
     * 三级校审新增或修改
     * @param jyProjectAuditDTO
     * @return
     * @throws Exception
     */
    public String saveFormThree(JyProjectAuditDTO jyProjectAuditDTO) throws Exception {
        //代码转化,将dto中的对象赋到实体类中
        JyProjectAudit jyProjectAudit = JyProjectAuditWrapper.INSTANCE.toEntity(jyProjectAuditDTO);
        //获取审核信息
        JyProjectAuditDTO byIdAudit = jyProjectAuditMapper.findByIdAudit(jyProjectAuditDTO.getId());
        if (ObjectUtil.isNotEmpty(byIdAudit)){
            String audit="";
            //对审核意见进行赋值
            if (StringUtils.isNotBlank(byIdAudit.getInitialAuditOpinion())){
                if (StringUtils.isNotBlank(jyProjectAuditDTO.getAuditOpinion())){
                    audit=byIdAudit.getInitialAuditOpinion()+"<br/>"+jyProjectAuditDTO.getAuditOpinion();
                }else {
                    audit=byIdAudit.getInitialAuditOpinion();
                }
            }else {
                audit=jyProjectAuditDTO.getAuditOpinion();
            }
            jyProjectAudit.setInitialAuditOpinion(audit);
            jyProjectAudit.setAuditOpinion("");
            //对修改意见赋值
            String edit="";
            if (StringUtils.isNotBlank(byIdAudit.getInitialEditOpinion())){
                if (StringUtils.isNotBlank(jyProjectAuditDTO.getEditOpinion())){
                    edit=byIdAudit.getInitialEditOpinion()+"<br/>"+jyProjectAuditDTO.getEditOpinion();
                }else {
                    edit=byIdAudit.getInitialEditOpinion();
                }
            }else {
                edit=jyProjectAuditDTO.getEditOpinion();
            }
            jyProjectAudit.setInitialEditOpinion(edit);
            jyProjectAudit.setEditOpinion("");
        }
        jyProjectAudit.setAuditPeople(jyProjectAuditDTO.getAuditPeople());
        if (StringUtils.isNotBlank(jyProjectAudit.getId())){
            jyProjectAuditMapper.updateById(jyProjectAudit);
        }else{
            jyProjectAuditMapper.insert(jyProjectAudit);
        }
        if (ObjectUtil.isNotEmpty(jyProjectAudit)) {
            //附件
            Map<String,String> map = new HashMap<>();
            String fileList = JSON.toJSONString((jyProjectAudit.getWorkAttachmentDtoList()));
            String attachmentId = jyProjectAudit.getId();
            String attachmentFlag = "jyProjectAudit";
            map.put("fileList",fileList);
            map.put("attachmentId",attachmentId);
            map.put("attachmentFlag",attachmentFlag);
            map.put("currentToken", TokenProvider.getCurrentToken ( ));
            SpringUtil.getBean ( IWorkAttachmentApi.class ).saveOrUpdateFileList(map);

        }
        return jyProjectAudit.getId();
    }

    /**
     * 根据id修改审核状态
     * @param dto
     * @return
     */
    public String updateStatusByAuditId(JyProjectAuditDTO dto) {
        JyProjectAudit jyProjectAudit = new JyProjectAudit();
        jyProjectAudit.setId(dto.getId());
        jyProjectAudit.setStatus(dto.getStatus());
        jyProjectAuditMapper.update(jyProjectAudit,new QueryWrapper<JyProjectAudit>().lambda().eq(JyProjectAudit::getId,jyProjectAudit.getId()));
        return "操作成功";
    }

    /**
     * 查询项目一级校审中逾期未发起的项目
     * @return
     */
    public List<JyProjectAudit> selectAudit() {
        //获取一个月前的时间
        //创建时间格式化对象
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        //获取当前时间
        Date currentDate = new Date();
        //将当前时间转化为字符串
        String format = simpleDateFormat.format(currentDate);
        //创建calendar对象
        Calendar instance = Calendar.getInstance();
        //将日期设置为当前时间
        instance.setTime(currentDate);
        //将日期往前推一个月
        instance.add(Calendar.MONTH,-1);
        //获取推送后的日期
        Date newDate = instance.getTime();
        List<JyProjectAudit> list=jyProjectAuditMapper.selectAudit(newDate);
        return list;
    }

    /**
     * 修改一级校审逾期状态
     * @param
     */
    public void updateStatus(String id) {
        JyProjectAuditDTO data = jyProjectAuditMapper.findByIdAudit(id);
        //判断一级校审是否发起
        if (StringUtils.isNotBlank(data.getStatus())){
            if (data.getStatus().equals("0")){
                jyProjectAuditMapper.updateStatus(data.getId());
            }
        }
            //判断一级校审是否在规定期限内完成
            if (StringUtils.isNotBlank(data.getExceedTimeStatus())){
                if (data.getExceedTimeStatus().equals("1")){
                    if (data.getStatus().equals("5")){
                        jyProjectAuditMapper.updateStatus2(data.getId());
                    }
                }
            }

    }

    /**
     * 查询校审数据信息并导出文档
     * @param info
     * @return
     */
    public Map<String,Object> getAuditInfoMap(JyProject info){
        Map data = new HashMap();

        SimpleDateFormat sdf = new SimpleDateFormat("yyyy年 MM月 dd日");

        //查询项目信息
        JyProjectDTO projectDTO = findById(info.getProjectId());

        //项目名称
        if(StringUtils.isNotBlank(projectDTO.getName())){
            data.put("projectName",projectDTO.getName());
        }else{
            data.put("projectName","");
        }
        //项目地点
        if (StringUtils.isNotBlank(projectDTO.getBuildPlace())){
            data.put("buildPlace",projectDTO.getBuildPlace());
        }else {
            data.put("buildPlace","");
        }
        //建设单位
        if (StringUtils.isNotBlank(projectDTO.getClientName())){
            data.put("clientName",projectDTO.getClientName());
        }else {
            data.put("clientName","");
        }
        //审批部门
        if (StringUtils.isNotBlank(projectDTO.getAuditOffice())){
            data.put("auditOffice",projectDTO.getAuditOffice());
        }else {
            data.put("auditOffice","");
        }
        //项目负责人
        if(StringUtils.isBlank(projectDTO.getLeader())){
            data.put("projectMaster","");
        }else{
            data.put("projectMaster",projectDTO.getLeader());
        }
        //其他参与人员
        if (ObjectUtil.isNotEmpty(projectDTO.getProjectMembers())){
            ArrayList<String> strings = new ArrayList<>();
            for (JyProjectMembers projectMember : projectDTO.getProjectMembers()) {
                strings.add(projectMember.getName());
            }
            data.put("otherPeople",strings);
        }else {
            data.put("otherPeople","");
        }
        //根据项目id获取到所有的校审信息
        List<JyProjectAuditDTO> jyProjectAuditDTOS=jyProjectAuditMapper.getByProjectId(info.getProjectId());
        //如果存在审核意见则进行处理
        if(null != jyProjectAuditDTOS){
            if (jyProjectAuditDTOS.size()>=1){
                //审核意见
                if (StringUtils.isNotBlank(jyProjectAuditDTOS.get(0).getInitialAuditOpinion())){
                    String[] split = jyProjectAuditDTOS.get(0).getInitialAuditOpinion().split("<br/>");
                    //将审核意见放入集合中
                    ArrayList<String> strings = new ArrayList<>();
                    for (String s : split) {
                        strings.add(s);
                    }
                    data.put("firstAuditList",strings);
                }else {
                    data.put("firstAuditList","");
                }
                //审核人
                if (StringUtils.isNotBlank(jyProjectAuditDTOS.get(0).getAuditPeople())){
                    data.put("firstAuditPeople",SpringUtil.getBean(IUserApi.class).getById(jyProjectAuditDTOS.get(0).getAuditPeople()).getName());
                }else {
                    data.put("firstAuditPeople","");

                }
                //日期
                String format = sdf.format(jyProjectAuditDTOS.get(0).getUpdateTime());
                if (null == jyProjectAuditDTOS.get(0).getUpdateTime()){
                    data.put("firstAuditDate","");
                    data.put("firstDate","");
                }else {
                    data.put("firstAuditDate",format);
                    data.put("firstDate",format);
                }
                //修改意见
                if (StringUtils.isNotBlank(jyProjectAuditDTOS.get(0).getInitialEditOpinion())){
                    String[] split = jyProjectAuditDTOS.get(0).getInitialEditOpinion().split("<br/>");
                    ArrayList<String> strings = new ArrayList<>();
                    for (String s : split) {
                        strings.add(s);
                    }
                    data.put("firstEditList",strings);
                }else {
                    data.put("firstEditList","");
                }
                //签名
                if (StringUtils.isNotBlank(jyProjectAuditDTOS.get(0).getCreateById())){
                    data.put("firstName",SpringUtil.getBean(IUserApi.class).getById(jyProjectAuditDTOS.get(0).getCreateById()).getName());
                }else {
                    data.put("firstName","");
                }
                //校核修改结果认可意见及签名和日期
                data.put("firstAgreeOpinion","");
                data.put("firstAgreeName","");
                data.put("firstAgreeDate","");

            } else if (jyProjectAuditDTOS.size()>=2){
                //审核意见
                if (StringUtils.isNotBlank(jyProjectAuditDTOS.get(1).getInitialAuditOpinion())){
                    String[] split = jyProjectAuditDTOS.get(1).getInitialAuditOpinion().split("<br/>");
                    //将审核意见放入集合中
                    ArrayList<String> strings = new ArrayList<>();
                    for (String s : split) {
                        strings.add(s);
                    }
                    data.put("secondAuditList",strings);
                }else {
                    data.put("secondAuditList","");

                }
                //审核人
                if (StringUtils.isNotBlank(jyProjectAuditDTOS.get(1).getAuditPeople())){
                    data.put("secondAuditPeople",SpringUtil.getBean(IUserApi.class).getById(jyProjectAuditDTOS.get(1).getAuditPeople()).getName());
                }else {
                    data.put("secondAuditPeople","");
                }
                //日期
                String format = sdf.format(jyProjectAuditDTOS.get(1).getUpdateTime());
                if (null == jyProjectAuditDTOS.get(1).getUpdateTime()){
                    data.put("secondAuditDate","");
                    data.put("secondDate","");
                }else {
                    data.put("secondAuditDate",format);
                    data.put("secondDate",format);
                }
                //修改意见
                if (StringUtils.isNotBlank(jyProjectAuditDTOS.get(1).getInitialEditOpinion())){
                    String[] split = jyProjectAuditDTOS.get(1).getInitialEditOpinion().split("<br/>");
                    ArrayList<String> strings = new ArrayList<>();
                    for (String s : split) {
                        strings.add(s);
                    }
                    data.put("secondEditList",strings);
                }else {
                    data.put("secondEditList","");
                }
                //签名及日期
                if (StringUtils.isNotBlank(jyProjectAuditDTOS.get(1).getCreateById())){
                    data.put("secondName",SpringUtil.getBean(IUserApi.class).getById(jyProjectAuditDTOS.get(1).getCreateById()).getName());
                }else {
                    data.put("secondName","");
                }
                //校核修改结果认可意见
                data.put("secondAgreeOpinion","");
                data.put("secondAgreeName","");
                data.put("secondAgreeDate","");


            }else if (jyProjectAuditDTOS.size()>=3){
                //审核意见
                if (StringUtils.isNotBlank(jyProjectAuditDTOS.get(2).getInitialAuditOpinion())){
                    String[] split = jyProjectAuditDTOS.get(2).getInitialAuditOpinion().split("<br/>");
                    //将审核意见放入集合中
                    ArrayList<String> strings = new ArrayList<>();
                    for (String s : split) {
                        strings.add(s);
                    }
                    data.put("thirdAuditList",strings);
                }else {
                    data.put("thirdAuditList","");
                }
                //审核人
                if (StringUtils.isNotBlank(jyProjectAuditDTOS.get(2).getAuditPeople())){
                    data.put("thirdAuditPeople",SpringUtil.getBean(IUserApi.class).getById(jyProjectAuditDTOS.get(2).getAuditPeople()).getName());
                }else {
                    data.put("thirdAuditPeople","");
                }
                //日期
                String format = sdf.format(jyProjectAuditDTOS.get(2).getUpdateTime());
                if (null == jyProjectAuditDTOS.get(2).getUpdateTime()){
                    data.put("thirdAuditDate","");
                    data.put("thirdDate","");
                }
                data.put("thirdAuditDate",format);
                data.put("thirdDate",format);
                //修改意见
                if (StringUtils.isNotBlank(jyProjectAuditDTOS.get(2).getInitialEditOpinion())){
                    String[] split = jyProjectAuditDTOS.get(2).getInitialEditOpinion().split("<br/>");
                    ArrayList<String> strings = new ArrayList<>();
                    for (String s : split) {
                        strings.add(s);
                    }
                    data.put("thirdEditList",strings);
                }else {
                    data.put("thirdEditList","");
                }
                //签名
                if (StringUtils.isNotBlank(jyProjectAuditDTOS.get(2).getCreateById())){
                    data.put("thirdName",SpringUtil.getBean(IUserApi.class).getById(jyProjectAuditDTOS.get(2).getCreateById()).getName());
                }else {
                    data.put("thirdName","");
                }
                //校核修改结果认可意见
                data.put("thirdAgreeOpinion","");
                data.put("thirdAgreeName","");
                data.put("thirdAgreeDate","");

            }
            //签发人
            data.put("submitPeople","");
            //签发日期
            data.put("submitDate","");
        }else{
            //一级复核意见
            data.put("firstAuditList","");
            //一级认可意见
            data.put("firstAgreeOpinion","");
            //一级审核人
            data.put("firstAuditPeople","");
            //一级认可签名
            data.put("firstAgreeName","");
            //一级审核日期
            data.put("firstAuditDate","");
            //一级认可日期
            data.put("firstAgreeDate","");
            //一级修改时间
            data.put("firstDate","");
            //一级修改意见
            data.put("firstEditList","");
            //一级修改人
            data.put("firstName","");
            //二级审核意见
            data.put("secondAuditList","");
            //二级认可意见
            data.put("secondAgreeOpinion","");
            //二级审核人
            data.put("secondAuditPeople","");
            //二级认可人
            data.put("secondAgreeName","");
            //二级审核时间
            data.put("secondAuditDate","");
            //二级认可时间
            data.put("secondAgreeDate","");
            //二级修改时间
            data.put("secondDate","");
            //二级修改意见
            data.put("secondEditList","");
            //二级修改人
            data.put("secondName","");
            //三级审核意见
            data.put("thirdAuditList","");
            //三级认可意见
            data.put("thirdAgreeOpinion","");
            //三级审核人
            data.put("thirdAuditPeople","");
            //三级认可人
            data.put("thirdAgreeName","");
            //三级审核日期
            data.put("thirdAuditDate","");
            //三级认可时间
            data.put("thirdAgreeDate","");
            //三级修改时间
            data.put("thirdDate","");
            //三级修改意见
            data.put("thirdEditList","");
            //三级修改人
            data.put("thirdName","");
            //签发人
            data.put("submitPeople","");
            //签发日期
            data.put("submitDate","");

        }
        return data;
    }




}
